==> freelancer-resume.9.0.zip: freelancer-resume/inc/customizer/theme-options/customize-sidebar.php <==
<?php

/**
 * Sidebar Theme Options
 *
 * @package freelancer-resume
 */
$wp_customize->add_section('freelancer_resume_sidebar_section', array(

	'title'      => esc_html__('Sidebar Section', 'freelancer-resume'),
	'capability' => 'edit_theme_options',
	'panel' => 'freelancer_resume_theme_section_panel'

));

//  Heading text color
$wp_customize->add_setting( 'freelancer_resume_sidebar_Hedingcolor' , array(
    'default'   => '#C63DC1',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_Hedingcolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Heading Color', 'freelancer-resume'),
    )));

    //  Heading bg color
$wp_customize->add_setting( 'freelancer_resume_sidebar_headingbgcolor' , array(
    'default'   => '#ECF5FF',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_headingbgcolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Heading Bg Color', 'freelancer-resume'),
    )));

    //  Search btn bg color
$wp_customize->add_setting( 'freelancer_resume_sidebar_searchbtncolor' , array(
    'default'   => '#C63DC1',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_searchbtncolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Search button Bg Color', 'freelancer-resume'),
    )));

    //  Search btn bg color
$wp_customize->add_setting( 'freelancer_resume_sidebar_searchtextcolor' , array(
    'default'   => '#fff',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_searchtextcolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Search button text Color', 'freelancer-resume'),
    )));

==> freelancer-resume.10.0.zip: freelancer-resume/inc/customizer/theme-options/customize-sidebar.php <==
<?php

/**
 * Sidebar Theme Options
 *
 * @package freelancer-resume
 */
$wp_customize->add_section('freelancer_resume_sidebar_section', array(

	'title'      => esc_html__('Sidebar Section', 'freelancer-resume'),
	'capability' => 'edit_theme_options',
	'panel' => 'freelancer_resume_theme_section_panel'

));

//  Heading text color
$wp_customize->add_setting( 'freelancer_resume_sidebar_Hedingcolor' , array(
    'default'   => '#C63DC1',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_Hedingcolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Heading Color', 'freelancer-resume'),
    )));

    //  Heading bg color
$wp_customize->add_setting( 'freelancer_resume_sidebar_headingbgcolor' , array(
    'default'   => '#ECF5FF',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_headingbgcolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Heading Bg Color', 'freelancer-resume'),
    )));

    //  Search btn bg color
$wp_customize->add_setting( 'freelancer_resume_sidebar_searchbtncolor' , array(
    'default'   => '#C63DC1',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_searchbtncolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Search button Bg Color', 'freelancer-resume'),
    )));

    //  Search btn bg color
$wp_customize->add_setting( 'freelancer_resume_sidebar_searchtextcolor' , array(
    'default'   => '#fff',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_searchtextcolor', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Search button text Color', 'freelancer-resume'),
    )));

    //  Heading border color
$wp_customize->add_setting( 'freelancer_resume_sidebar_headingborder' , array(
    'default'   => '#C63DC1',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'freelancer_resume_sidebar_headingborder', array(
    'section' => 'freelancer_resume_sidebar_section',
    'label'      => esc_html__('Heading border Color', 'freelancer-resume'),
    )));
